'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var require$$0 = require('@backstage/plugin-scaffolder-backend');
var require$$1 = require('@kubernetes/client-node');
var require$$2 = require('js-yaml');
var require$$1$1 = require('fs/promises');
var require$$2$1 = require('path');
var require$$3 = require('@backstage/backend-common');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var require$$0__default = /*#__PURE__*/_interopDefaultLegacy(require$$0);
var require$$1__default = /*#__PURE__*/_interopDefaultLegacy(require$$1);
var require$$2__default = /*#__PURE__*/_interopDefaultLegacy(require$$2);
var require$$1__default$1 = /*#__PURE__*/_interopDefaultLegacy(require$$1$1);
var require$$2__default$1 = /*#__PURE__*/_interopDefaultLegacy(require$$2$1);
var require$$3__default = /*#__PURE__*/_interopDefaultLegacy(require$$3);

var index_cjs$1 = {};

Object.defineProperty(index_cjs$1, '__esModule', { value: true });

var pluginScaffolderBackend$1 = require$$0__default["default"];
var clientNode = require$$1__default["default"];
var yaml = require$$2__default["default"];

function _interopNamespace$2(e) {
	if (e && e.__esModule) return e;
	var n = Object.create(null);
	if (e) {
		Object.keys(e).forEach(function (k) {
			if (k !== 'default') {
				var d = Object.getOwnPropertyDescriptor(e, k);
				Object.defineProperty(n, k, d.get ? d : {
					enumerable: true,
					get: function () { return e[k]; }
				});
			}
		});
	}
	n["default"] = e;
	return Object.freeze(n);
}

var yaml__namespace = /*#__PURE__*/_interopNamespace$2(yaml);

const deployKubernetesAction = () => {
  return pluginScaffolderBackend$1.createTemplateAction({
    id: "deploy:kubernetes",
    description: "Applies a Kubernetes manifest",
    schema: {
      input: {
        type: "object",
        properties: {
          manifest: {
            title: "Kubernetes Manifest",
            description: "YAML or JSON manifest for the Kubernetes resource to be applied",
            type: "any"
          },
          clusterUrl: {
            title: "Cluster URL",
            description: "URL of the Kubernetes API",
            type: "string"
          },
          authToken: {
            title: "Token",
            description: "Bearer token to authenticate with the Kubernetes API",
            type: "string"
          }
        },
        required: ["manifest", "clusterUrl", "authToken"]
      }
    },
    async handler(ctx) {
      var _a, _b;
      const manifest = ctx.input.manifest;
      const clusterUrl = ctx.input.clusterUrl;
      const token = ctx.input.authToken;
      console.log(
        `Type of content: ${typeof manifest}, Content preview: ${manifest}`
      );
      const kubeConfig = new clientNode.KubeConfig();
      kubeConfig.loadFromOptions({
        clusters: [
          {
            name: "dynamic-cluster",
            server: clusterUrl,
            skipTLSVerify: true
          }
        ],
        users: [
          {
            name: "dynamic-user",
            token
          }
        ],
        contexts: [
          {
            name: "dynamic-context",
            user: "dynamic-user",
            cluster: "dynamic-cluster"
          }
        ],
        currentContext: "dynamic-context"
      });
      const api = kubeConfig.makeApiClient(clientNode.KubernetesObjectApi);
      const resources = yaml__namespace.loadAll(manifest);
      if (!resources || !Array.isArray(resources) || resources.length === 0) {
        throw new Error(
          "Invalid manifest: must contain at least one valid YAML or JSON object"
        );
      }
      for (const resource of resources) {
        try {
          const result = await api.create(resource);
          ctx.logger.info(
            `Successfully applied manifest for ${resource.kind}/${(_a = resource.metadata) == null ? void 0 : _a.name}: ${result}`
          );
        } catch (error) {
          ctx.logger.error(
            `Failed to apply Kubernetes manifest for ${resource.kind}/${(_b = resource.metadata) == null ? void 0 : _b.name}: ${error}`
          );
        }
      }
    }
  });
};

var deployKubernetesAction_1 = index_cjs$1.deployKubernetesAction = deployKubernetesAction;

var index_cjs = {};

Object.defineProperty(index_cjs, '__esModule', { value: true });

var pluginScaffolderBackend = require$$0__default["default"];
var fs = require$$1__default$1["default"];
var path = require$$2__default$1["default"];
var backendCommon = require$$3__default["default"];

function _interopNamespace$1(e) {
	if (e && e.__esModule) return e;
	var n = Object.create(null);
	if (e) {
		Object.keys(e).forEach(function (k) {
			if (k !== 'default') {
				var d = Object.getOwnPropertyDescriptor(e, k);
				Object.defineProperty(n, k, d.get ? d : {
					enumerable: true,
					get: function () { return e[k]; }
				});
			}
		});
	}
	n["default"] = e;
	return Object.freeze(n);
}

var fs__namespace = /*#__PURE__*/_interopNamespace$1(fs);

const readFileAction = () => {
  return pluginScaffolderBackend.createTemplateAction({
    id: "read:file",
    description: "Reads the content of a file and returns it.",
    schema: {
      input: {
        type: "object",
        properties: {
          filename: {
            type: "string",
            description: "The name of the file to read.",
            minLength: 1
          },
          path: {
            type: "string",
            description: 'The optional path to the directory containing the file. Defaults to the "generated" directory if not provided.'
          }
        },
        required: ["filename"]
      },
      output: {
        type: "object",
        properties: {
          content: {
            type: "string"
          }
        }
      }
    },
    async handler(ctx) {
      try {
        const defaultPath = path.resolve(ctx.workspacePath);
        const basePath = ctx.input.path ? path.resolve(ctx.workspacePath, ctx.input.path) : defaultPath;
        const safeBasePath = backendCommon.resolveSafeChildPath(ctx.workspacePath, basePath);
        const safeFilePath = path.resolve(
          safeBasePath,
          ctx.input.filename
        );
        const finalPath = backendCommon.resolveSafeChildPath(safeBasePath, safeFilePath);
        const content = await fs__namespace.readFile(finalPath, "utf8");
        console.log(
          `Type of content: ${typeof content}, Content preview: ${content.substring(
            0,
            100
          )}`
        );
        ctx.output("content", content);
      } catch (error) {
        if (error instanceof Error) {
          throw new Error(`Failed to read file: ${error.message}`);
        } else {
          throw new Error("Failed to read file: An unknown error occurred");
        }
      }
    }
  });
};

var readFileAction_1 = index_cjs.readFileAction = readFileAction;

const dynamicPluginInstaller = {
  kind: "legacy",
  scaffolder: () => [deployKubernetesAction_1(), readFileAction_1()]
};

exports.dynamicPluginInstaller = dynamicPluginInstaller;
//# sourceMappingURL=index.cjs.js.map
